==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/tests/playlistmanager/sql/TestSqlUserPlaylistProvider.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@asbest-online.de>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTSQLUSERPLAYLISTPROVIDER_H
#define TESTSQLUSERPLAYLISTPROVIDER_H

#include <QtCore/QObject>
#include <QtCore/QString>

namespace Playlists {
    class SqlUserPlaylistProvider;
}

class TestSqlUserPlaylistProvider : public QObject
{
Q_OBJECT

public:
    TestSqlUserPlaylistProvider();

private slots:
    void initTestCase();
    void cleanupTestCase();
    void testPlaylists();
    void testSave();
    void testRename();
    void testDelete();

private:
    Playlists::SqlUserPlaylistProvider *m_testSqlUserPlaylistProvider;
    QString dataPath( const QString &relPath );
};

#endif // TESTSQLUSERPLAYLISTPROVIDER_H

==> amarok_3.3.1.orig.tar.xz: amarok-3.3.1/tests/playlistmanager/sql/TestSqlUserPlaylistProvider.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@asbest-online.de>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTSQLUSERPLAYLISTPROVIDER_H
#define TESTSQLUSERPLAYLISTPROVIDER_H

#include <QObject>
#include <QString>

namespace Playlists {
    class SqlUserPlaylistProvider;
}

class TestSqlUserPlaylistProvider : public QObject
{
Q_OBJECT

public:
    TestSqlUserPlaylistProvider();

private Q_SLOTS:
    void initTestCase();
    void cleanupTestCase();
    void testPlaylists();
    void testSave();
    void testRename();
    void testDelete();

private:
    Playlists::SqlUserPlaylistProvider *m_testSqlUserPlaylistProvider;
    QString dataPath( const QString &relPath );
};

#endif // TESTSQLUSERPLAYLISTPROVIDER_H
